@@ -3,10 +3,16 @@ Mac OS X .app build command for distutils
 
 Originally (loosely) based on code from py2exe's build_exe.py by Thomas Heller.
 """
+
 from __future__ import print_function
 
 import collections
-import imp
+
+try:
+    import imp
+except ImportError:
+    from modulegraph import _imp as imp
+
 import os
 import plistlib
 import shlex
@@ -23,7 +29,7 @@ from itertools import chain
 import macholib.dyld
 import macholib.MachO
 import macholib.MachOStandalone
-import pkg_resources
+
 from macholib.util import flipwritable
 from modulegraph import modulegraph, zipio
 from modulegraph.find_modules import find_modules, find_needed_modules, parse_mf_results
@@ -58,6 +64,7 @@ from py2app.util import (
     skipscm,
     strip_files,
 )
+from py2app.build_support import FixupTargets
 
 try:
     from cStringIO import StringIO
@@ -91,39 +98,6 @@ else:
     sys_base_prefix = sys.prefix
 
 
-def finalize_distribution_options(dist):
-    """
-    setuptools.finalize_distribution_options extension
-    point for py2app, to deail with autodiscovery in
-    setuptools 61.
-
-    This addin will set the name and py_modules attributes
-    when a py2app distribution is detected that does not
-    yet have these attributes.
-    are not already set
-    """
-    if getattr(dist, "app", None) is None and getattr(dist, "plugin", None) is None:
-        return
-
-    if getattr(dist.metadata, "py_modules", None) is None:
-        dist.py_modules = []
-
-    name = getattr(dist.metadata, "name", None)
-    if name is None or name == "UNKNOWN":
-        if dist.app:
-            targets = FixupTargets(dist.app, "script")
-        else:
-            targets = FixupTargets(dist.plugin, "script")
-
-        if not targets:
-            return
-
-        base = targets[0].get_dest_base()
-        name = os.path.basename(base)
-
-        dist.metadata.name = name
-
-
 def loader_paths(sourcefn, destfn):
     # Yield (sourcefn, destfn) pairs for all
     # '@loader_path' load commands in 'sourcefn'
@@ -186,9 +160,9 @@ def rewrite_tkinter_load_commands(tkinter_path):
                 "_tkinter is linked to a version of Tcl not in /System"
             )
 
-        rewrite_map[
-            tcl_path
-        ] = "/System/Library/Frameworks/Tcl.framework/Versions/%s/Tcl" % (ver,)
+        rewrite_map[tcl_path] = (
+            "/System/Library/Frameworks/Tcl.framework/Versions/%s/Tcl" % (ver,)
+        )
 
     if not tk_path.startswith("/System/Library/Frameworks"):
         # ../Versions/8.5/Tk
@@ -198,9 +172,9 @@ def rewrite_tkinter_load_commands(tkinter_path):
                 "_tkinter is linked to a version of Tk not in /System"
             )
 
-        rewrite_map[
-            tk_path
-        ] = "/System/Library/Frameworks/Tk.framework/Versions/%s/Tk" % (ver,)
+        rewrite_map[tk_path] = (
+            "/System/Library/Frameworks/Tk.framework/Versions/%s/Tk" % (ver,)
+        )
 
     if rewrite_map:
         print("Relinking _tkinter.so to system Tcl/Tk")
@@ -241,9 +215,24 @@ def get_zipfile(dist, semi_standalone=False):
     return getattr(dist, "zipfile", None) or "site-packages.zip"
 
 
+# This is a crude hack, ignore some Tcl/Tk files that cause code signing errors
+# with CPython's 3.13 and 3.14 installers.
+_IGNORE_FILES = [
+    "tclooConfig.sh",
+    "tclConfig.sh",
+    "tkConfig.sh",
+    "libtkstub8.6.a",
+    "libtclstub8.6.a",
+]
+
+
 def framework_copy_condition(src):
     # Skip Headers, .svn, and CVS dirs
-    return skipscm(src) and os.path.basename(src) != "Headers"
+    return (
+        skipscm(src)
+        and os.path.basename(src) != "Headers"
+        and not os.path.basename(src) in _IGNORE_FILES
+    )
 
 
 class PythonStandalone(macholib.MachOStandalone.MachOStandalone):
@@ -302,72 +291,6 @@ def iterRecipes(module=recipes):
             yield (name, check)
 
 
-# A very loosely defined "target".  We assume either a "script" or "modules"
-# attribute.  Some attributes will be target specific.
-class Target(object):
-    def __init__(self, **kw):
-        self.__dict__.update(kw)
-        # If modules is a simple string, assume they meant list
-        m = self.__dict__.get("modules")
-        if m and isinstance(m, basestring):
-            self.modules = [m]
-
-    def __repr__(self):
-        return "<Target %s>" % (self.__dict__,)
-
-    def get_dest_base(self):
-        dest_base = getattr(self, "dest_base", None)
-        if dest_base:
-            return dest_base
-
-        script = getattr(self, "script", None)
-        if script:
-            return os.path.basename(os.path.splitext(script)[0])
-        modules = getattr(self, "modules", None)
-        assert modules, "no script, modules or dest_base specified"
-        return modules[0].split(".")[-1]
-
-    def validate(self):
-        resources = getattr(self, "resources", [])
-        for r_filename in resources:
-            if not os.path.isfile(r_filename):
-                raise DistutilsOptionError(
-                    "Resource filename '%s' does not exist" % (r_filename,)
-                )
-
-
-def validate_target(dist, attr, value):
-    res = FixupTargets(value, "script")
-    other = {"app": "plugin", "plugin": "app"}
-    if res and getattr(dist, other[attr]):
-        raise DistutilsOptionError("You must specify either app or plugin, not both")
-
-
-def FixupTargets(targets, default_attribute):
-    if not targets:
-        return targets
-    try:
-        targets = eval(targets)
-    except:  # noqa: E722,B001
-        pass
-    ret = []
-    for target_def in targets:
-        if isinstance(target_def, basestring):
-            # Create a default target object, with the string as the attribute
-            target = Target(**{default_attribute: target_def})
-        else:
-            d = getattr(target_def, "__dict__", target_def)
-            if default_attribute not in d:
-                raise DistutilsOptionError(
-                    "This target class requires an attribute '%s'"
-                    % (default_attribute,)
-                )
-            target = Target(**d)
-        target.validate()
-        ret.append(target)
-    return ret
-
-
 def normalize_data_file(fn):
     if isinstance(fn, basestring):
         fn = convert_path(fn)
@@ -731,13 +654,16 @@ class py2app(Command):
         # included by apptemplate
         self.excludes.add("site")
         if getattr(self.distribution, "install_requires", None):
-            self.includes.add("pkg_resources")
-            self.eggs = pkg_resources.require(self.distribution.install_requires)
+            raise DistutilsOptionError("install_requires is no longer supported")
 
         # Setuptools/distribute style namespace packages uses
         # __import__('pkg_resources'), and that import isn't detected at the
         # moment. Forcefully include pkg_resources.
-        self.includes.add("pkg_resources")
+        if sys.version_info[:2] < (3, 9):
+            self.includes.add("pkg_resources")
+
+        elif sys.version_info[:2] < (3, 12):
+            self.includes.add("imp")
 
         dylib_excludes = fancy_split(self.dylib_excludes)
         self.dylib_excludes = []
@@ -986,9 +912,7 @@ class py2app(Command):
             sys.path = sys_old_path
 
     def iter_datamodels(self, resdir):
-        for (path, files) in (
-            normalize_data_file(fn) for fn in (self.datamodels or ())
-        ):
+        for path, files in (normalize_data_file(fn) for fn in (self.datamodels or ())):
             path = fsencoding(path)
             for fn in files:
                 fn = fsencoding(fn)
@@ -1006,7 +930,7 @@ class py2app(Command):
             momc(src, dest)
 
     def iter_mappingmodels(self, resdir):
-        for (path, files) in (
+        for path, files in (
             normalize_data_file(fn) for fn in (self.mappingmodels or ())
         ):
             path = fsencoding(path)
@@ -1044,7 +968,7 @@ class py2app(Command):
     def iter_data_files(self):
         dist = self.distribution
         allres = chain(getattr(dist, "data_files", ()) or (), self.resources)
-        for (path, files) in (normalize_data_file(fn) for fn in allres):
+        for path, files in (normalize_data_file(fn) for fn in allres):
             path = fsencoding(path)
             for fn in files:
                 fn = fsencoding(fn)
@@ -1384,6 +1308,8 @@ class py2app(Command):
             if missing_unconditional:
                 warnings = []
                 for m in sorted(missing_unconditional):
+                    if m.endswith(".__main__"):
+                        continue
                     try:
                         if "." in m:
                             m1, m2 = m.rsplit(".", 1)
@@ -1402,7 +1328,18 @@ class py2app(Command):
                                 continue
 
                         else:
-                            o = __import__(m)
+                            try:
+                                o = __import__(m)
+                            except Exception:
+                                if self.may_log_missing(m):
+                                    warnings.append(
+                                        " * %s (%s)"
+                                        % (
+                                            m,
+                                            ", ".join(sorted(missing_unconditional[m])),
+                                        )
+                                    )
+                                continue
 
                         if isinstance(o, types.ModuleType):
                             if self.may_log_missing(m):
@@ -1427,6 +1364,7 @@ class py2app(Command):
             if missing_conditional and not self.no_report_missing_conditional_import:
                 warnings = []
                 for m in sorted(missing_conditional):
+                    print("missing conditional", m)
                     try:
                         if "." in m:
                             m1, m2 = m.rsplit(".", 1)
@@ -1638,7 +1576,7 @@ class py2app(Command):
         # copy package metadata
         for pkg_info_path in included_metadata:
             base = os.path.join(self.collect_dir, os.path.basename(pkg_info_path))
-            os.mkdir(base)
+            os.makedirs(base, exist_ok=True)
 
             for fn in os.listdir(pkg_info_path):
                 if fn in IGNORED_DISTINFO:
@@ -2596,7 +2534,8 @@ class py2app(Command):
         # Also, we don't append '.zip' to the filename.
         from distutils.dir_util import mkpath
 
-        mkpath(os.path.dirname(zip_filename), dry_run=dry_run)
+        if not dry_run:
+            mkpath(os.path.dirname(zip_filename))
 
         if self.compressed:
             compression = zipfile.ZIP_DEFLATED
