@@ -33,7 +33,7 @@ class TestBasicApp (unittest.TestCase):
 
         env=os.environ.copy()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
-        env['TMPDIR'] = os.getcwd()
+        #env['TMPDIR'] = os.getcwd()
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
         else:
@@ -49,7 +49,7 @@ class TestBasicApp (unittest.TestCase):
             env=env)
         lines = p.communicate()[0]
         if p.wait() != 0:
-            print (lines)
+            print (lines.decode())
             raise AssertionError("Creating basic_app bundle failed")
 
     @classmethod
