@@ -79,7 +79,7 @@ class TestBasicApp (unittest.TestCase):
         cls.class_cleanup()
 
         env=os.environ.copy()
-        env['TMPDIR'] = os.getcwd()
+        #env['TMPDIR'] = os.getcwd()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
