@@ -48,7 +48,7 @@ class TestBasicPlugin (unittest.TestCase):
             cmd = [ sys.executable, 'setup.py', 'py2app'] + cls.py2app_args
 
             env=os.environ.copy()
-            env['TMPDIR'] = os.getcwd()
+            #env['TMPDIR'] = os.getcwd()
             pp = os.path.dirname(os.path.dirname(py2app.__file__))
             if 'PYTHONPATH' in env:
                 env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
@@ -148,7 +148,7 @@ class TestBasicPlugin (unittest.TestCase):
             os.unlink('bundle_loader')
 
         if os.path.exists('bundle_loader.dSYM'):
-            os.rmtree('bundle_loader.dSYM')
+            shutil.rmtree('bundle_loader.dSYM')
 
         if os.path.exists(os.path.join(cls.plugin_dir, 'build')):
             shutil.rmtree(os.path.join(cls.plugin_dir, 'build'))
