@@ -35,7 +35,7 @@ class TestBasicApp (unittest.TestCase):
 
         env=os.environ.copy()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
-        env['TMPDIR'] = os.getcwd()
+        #env['TMPDIR'] = os.getcwd()
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
         else:
