@@ -20,7 +20,7 @@ class TestPy2Applet (unittest.TestCase):
 
     def run_py2applet(self, *args):
         env=os.environ.copy()
-        env['TMPDIR'] = os.getcwd()
+        #env['TMPDIR'] = os.getcwd()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
